pub struct AgentService { /* private fields */ }Trait Implementations
Sourceimpl BackgroundService for AgentService
impl BackgroundService for AgentService
Sourcefn start<'life0, 'async_trait>(
&'life0 self,
shutdown: ShutdownWatch,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn start<'life0, 'async_trait>(
&'life0 self,
shutdown: ShutdownWatch,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
This function is called when the pingora server tries to start all the
services. The background service can return at anytime or wait for the
shutdown signal.Sourcefn start_with_ready_notifier<'life0, 'async_trait>(
&'life0 self,
shutdown: Receiver<bool>,
ready_notifier: ServiceReadyNotifier,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: Sync + 'async_trait,
fn start_with_ready_notifier<'life0, 'async_trait>(
&'life0 self,
shutdown: Receiver<bool>,
ready_notifier: ServiceReadyNotifier,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: Sync + 'async_trait,
This function is called when the pingora server tries to start all the
services. The background service should signal readiness by calling
ready_notifier.notify_ready() once initialization is complete.
The service can return at anytime or wait for the shutdown signal. Read moreAuto Trait Implementations
impl Freeze for AgentService
impl RefUnwindSafe for AgentService
impl Send for AgentService
impl Sync for AgentService
impl Unpin for AgentService
impl UnsafeUnpin for AgentService
impl UnwindSafe for AgentService